/****************************************************************************/
/*	Copyright (c) 2009, Bendor Research Pty. Ltd. All rights reserved.		*/
/*	This software is released under the GNU General Public License, version	*/
/*	3, with the exemptions that 1) the header files installed by this 	 	*/
/*	package can be included in closed-source code and 2) the libraries		*/
/*	built by this package can be statically linked into a closed-source 	*/
/*	binary. See the file LICENSE for the details.							*/
/*	This software is provided "AS IS", without any warranty or guarantee.	*/
/*	By using this software you acknowledge that neither Bendor Research nor	*/
/*	any of its personnel or affiliates can be held liable for any damages,	*/
/*	including, but not limited to, loss of business, loss of money, loss of */
/*	life, loss of reputation, arising out of this software being faulty or	*/
/*	not performing as advertised, even if Bendor Research was aware of such	*/
/*	faults in the software. You use this software at your own risk, any and */
/*	all liabilities that arise out of your using this software are strictly	*/
/*	yours.																	*/
/****************************************************************************/

#include <string.h>

/** @addtogroup string */
/** @{ */

/**
*	Copies a memory range to an other.
*
*	The function copies \p len bytes from the memory area pointed by \p src
*	to the memory are pointed by \p dst and returns \p dst.
*	The copy will be performed starting with the end of the memory areas,
*	therefore the areas can overlap if the destination address is larger
*	than the source address.
*
*	@param	dst	Pointer to the destination memory range
*	@param	src	Pointer to the source memory range
*	@param	len	The number of bytes to copy
*	@return		The value of dst
*
*	@note
*		This is a non-standard function.
*/

void	*memrcpy( void *dst, const void *src, size_t len )
{
char	*s = (char *) src + len;
char	*d = (char *) dst + len;

	while ( len-- ) *--d = *--s;
	return( dst );
}

/** @} */

